@@ -1,6 +1,6 @@
-from pysjtu.ocr import LegacyRecognizer, NNRecognizer
+from pysjtu.ocr import LegacyRecognizer, NNRecognizer, JCSSRecognizer
 from .client import Client, create_client
 from .models import CourseRange, LogicEnum, Ranking
 from .session import Session
 
-__version__ = "0.3.0"
+__version__ = "0.3.1"
